@@ -1,3 +1,5 @@
+from typing import override
+
 from archinstall.default_profiles.profile import GreeterType, ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
 
@@ -7,6 +9,7 @@ class BspwmProfile(XorgProfile):
 		super().__init__('Bspwm', ProfileType.WindowMgr, description='')
 
 	@property
+	@override
 	def packages(self) -> list[str]:
 		# return super().packages + [
 		return [
@@ -18,5 +21,6 @@ class BspwmProfile(XorgProfile):
 		]
 
 	@property
+	@override
 	def default_greeter_type(self) -> GreeterType | None:
 		return GreeterType.Lightdm
