@@ -1,3 +1,5 @@
+from typing import override
+
 from archinstall.default_profiles.profile import GreeterType, ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
 
@@ -7,6 +9,7 @@ class BudgieProfile(XorgProfile):
 		super().__init__('Budgie', ProfileType.DesktopEnv, description='')
 
 	@property
+	@override
 	def packages(self) -> list[str]:
 		return [
 			"arc-gtk-theme",
@@ -17,5 +20,6 @@ class BudgieProfile(XorgProfile):
 		]
 
 	@property
+	@override
 	def default_greeter_type(self) -> GreeterType | None:
 		return GreeterType.LightdmSlick
