@@ -1,12 +1,15 @@
+from typing import override
+
 from archinstall.default_profiles.profile import GreeterType, ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
 
 
 class GnomeProfile(XorgProfile):
 	def __init__(self) -> None:
-		super().__init__('Gnome', ProfileType.DesktopEnv, description='')
+		super().__init__('GNOME', ProfileType.DesktopEnv, description='')
 
 	@property
+	@override
 	def packages(self) -> list[str]:
 		return [
 			'gnome',
@@ -14,5 +17,6 @@ class GnomeProfile(XorgProfile):
 		]
 
 	@property
+	@override
 	def default_greeter_type(self) -> GreeterType | None:
 		return GreeterType.Gdm
