@@ -1,3 +1,5 @@
+from typing import override
+
 from archinstall.default_profiles.profile import GreeterType, ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
 
@@ -10,6 +12,7 @@ class LxqtProfile(XorgProfile):
 	# LXQt works with lightdm, but since this is not supported, we will not default to this.
 	# https://github.com/lxqt/lxqt/issues/795
 	@property
+	@override
 	def packages(self) -> list[str]:
 		return [
 			"lxqt",
@@ -22,5 +25,6 @@ class LxqtProfile(XorgProfile):
 		]
 
 	@property
+	@override
 	def default_greeter_type(self) -> GreeterType | None:
 		return GreeterType.Sddm
