@@ -1,3 +1,5 @@
+from typing import override
+
 from archinstall.default_profiles.profile import GreeterType, ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
 
@@ -7,17 +9,18 @@ class PlasmaProfile(XorgProfile):
 		super().__init__('KDE Plasma', ProfileType.DesktopEnv, description='')
 
 	@property
+	@override
 	def packages(self) -> list[str]:
 		return [
 			"plasma-meta",
 			"konsole",
-			"kwrite",
+			"kate",
 			"dolphin",
 			"ark",
-			"plasma-workspace",
-			"egl-wayland"
+			"plasma-workspace"
 		]
 
 	@property
+	@override
 	def default_greeter_type(self) -> GreeterType | None:
 		return GreeterType.Sddm
