@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, override
 
 import archinstall
 from archinstall.default_profiles.profile import Profile, ProfileType
@@ -16,13 +16,16 @@ class DockerProfile(Profile):
 		)
 
 	@property
+	@override
 	def packages(self) -> list[str]:
 		return ['docker']
 
 	@property
+	@override
 	def services(self) -> list[str]:
 		return ['docker']
 
+	@override
 	def post_install(self, install_session: 'Installer') -> None:
 		users: User | list[User] = archinstall.arguments.get('!users', [])
 		if not isinstance(users, list):
