@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, override
 
 from archinstall.default_profiles.profile import ProfileType
 from archinstall.default_profiles.xorg import XorgProfile
@@ -12,9 +12,11 @@ class TailoredProfile(XorgProfile):
 		super().__init__('52-54-00-12-34-56', ProfileType.Tailored, description='')
 
 	@property
+	@override
 	def packages(self) -> list[str]:
 		return ['nano', 'wget', 'git']
 
+	@override
 	def install(self, install_session: 'Installer') -> None:
 		super().install(install_session)
 		# do whatever you like here :)
