@@ -76,7 +76,7 @@ def _only_hd() -> None:
 	)
 
 	fs_handler.perform_filesystem_operations()
-	perform_installation(archinstall.storage.get('MOUNT_POINT', Path('/mnt')))
+	perform_installation(archinstall.arguments.get('mount_point', Path('/mnt')))
 
 
 _only_hd()
