@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import time
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 
 from archinstall.tui import Tui
 
@@ -28,7 +28,11 @@ from .device_model import (
 )
 
 if TYPE_CHECKING:
-	_: Any
+	from collections.abc import Callable
+
+	from archinstall.lib.translationhandler import DeferredTranslation
+
+	_: Callable[[str], DeferredTranslation]
 
 
 class FilesystemHandler:
@@ -45,7 +49,7 @@ class FilesystemHandler:
 			debug('Disk layout configuration is set to pre-mount, not performing any operations')
 			return
 
-		device_mods = list(filter(lambda x: len(x.partitions) > 0, self._disk_config.device_modifications))
+		device_mods = [d for d in self._disk_config.device_modifications if d.partitions]
 
 		if not device_mods:
 			debug('No modifications required')
@@ -69,6 +73,8 @@ class FilesystemHandler:
 		for mod in device_mods:
 			device_handler.partition(mod, partition_table=partition_table)
 
+		device_handler.udev_sync()
+
 		if self._disk_config.lvm_config:
 			for mod in device_mods:
 				if boot_part := mod.get_boot_partition():
