@@ -2,7 +2,6 @@ from __future__ import annotations
 
 import json
 import os
-import pathlib
 import re
 import secrets
 import shlex
@@ -16,9 +15,10 @@ import urllib.parse
 from collections.abc import Callable, Iterator
 from datetime import date, datetime
 from enum import Enum
+from pathlib import Path
 from select import EPOLLHUP, EPOLLIN, epoll
 from shutil import which
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, override
 from urllib.request import Request, urlopen
 
 from .exceptions import RequirementError, SysCallError
@@ -73,7 +73,7 @@ def jsonify(obj: Any, safe: bool = True) -> Any:
 		return obj.isoformat()
 	if isinstance(obj, list | set | tuple):
 		return [jsonify(item, safe) for item in obj]
-	if isinstance(obj, pathlib.Path):
+	if isinstance(obj, Path):
 		return str(obj)
 	if hasattr(obj, "__dict__"):
 		return vars(obj)
@@ -86,6 +86,7 @@ class JSON(json.JSONEncoder, json.JSONDecoder):
 	A safe JSON encoder that will omit private information in dicts (starting with !)
 	"""
 
+	@override
 	def encode(self, o: Any) -> str:
 		return super().encode(jsonify(o))
 
@@ -95,6 +96,7 @@ class UNSAFE_JSON(json.JSONEncoder, json.JSONDecoder):
 	UNSAFE_JSON will call/encode and keep private information in dicts (starting with !)
 	"""
 
+	@override
 	def encode(self, o: Any) -> str:
 		return super().encode(jsonify(o, safe=False))
 
@@ -105,26 +107,25 @@ class SysCommandWorker:
 		cmd: str | list[str],
 		callbacks: dict[str, Any] | None = None,
 		peek_output: bool | None = False,
-		environment_vars: dict[str, Any] | None = None,
+		environment_vars: dict[str, str] | None = None,
 		logfile: None = None,
 		working_directory: str | None = './',
 		remove_vt100_escape_codes_from_lines: bool = True
 	):
-		callbacks = callbacks or {}
-		environment_vars = environment_vars or {}
-
 		if isinstance(cmd, str):
 			cmd = shlex.split(cmd)
 
-		if cmd:
-			if cmd[0][0] != '/' and cmd[0][:2] != './':  # pathlib.Path does not work well
-				cmd[0] = locate_binary(cmd[0])
+		if cmd and not cmd[0].startswith(('/', './')):  # Path() does not work well
+			cmd[0] = locate_binary(cmd[0])
 
 		self.cmd = cmd
-		self.callbacks = callbacks
+		self.callbacks = callbacks or {}
 		self.peek_output = peek_output
 		# define the standard locale for command outputs. For now the C ascii one. Can be overridden
-		self.environment_vars = {**storage.get('CMD_LOCALE', {}), **environment_vars}
+		self.environment_vars = {'LC_ALL': 'C'}
+		if environment_vars:
+			self.environment_vars.update(environment_vars)
+
 		self.logfile = logfile
 		self.working_directory = working_directory
 
@@ -156,16 +157,18 @@ class SysCommandWorker:
 		lines = filter(None, self._trace_log[self._trace_log_pos:last_line].splitlines())
 		for line in lines:
 			if self.remove_vt100_escape_codes_from_lines:
-				line = clear_vt100_escape_codes(line)  # type: ignore
+				line = clear_vt100_escape_codes(line)  # type: ignore[assignment]
 
 			yield line + b'\n'
 
 		self._trace_log_pos = last_line
 
+	@override
 	def __repr__(self) -> str:
 		self.make_sure_we_are_executing()
 		return str(self._trace_log)
 
+	@override
 	def __str__(self) -> str:
 		try:
 			return self._trace_log.decode('utf-8')
@@ -182,7 +185,7 @@ class SysCommandWorker:
 		if self.child_fd:
 			try:
 				os.close(self.child_fd)
-			except:
+			except Exception:
 				pass
 
 		if self.peek_output:
@@ -216,7 +219,6 @@ class SysCommandWorker:
 
 		if self.child_fd:
 			return os.write(self.child_fd, data + (b'\n' if line_ending else b''))
-			os.fsync(self.child_fd)
 
 		return 0
 
@@ -242,7 +244,7 @@ class SysCommandWorker:
 				except UnicodeDecodeError:
 					return False
 
-			peak_logfile = pathlib.Path(f"{storage['LOG_PATH']}/cmd_output.txt")
+			peak_logfile = Path(f"{storage['LOG_PATH']}/cmd_output.txt")
 
 			change_perm = False
 			if peak_logfile.exists() is False:
@@ -252,7 +254,7 @@ class SysCommandWorker:
 				peek_output_log.write(str(output))
 
 			if change_perm:
-				os.chmod(str(peak_logfile), stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
+				peak_logfile.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
 
 			sys.stdout.write(str(output))
 			sys.stdout.flush()
@@ -264,7 +266,7 @@ class SysCommandWorker:
 
 		if self.child_fd:
 			got_output = False
-			for fileno, event in self.poll_object.poll(0.1):
+			for _fileno, _event in self.poll_object.poll(0.1):
 				try:
 					output = os.read(self.child_fd, 8192)
 					got_output = True
@@ -301,7 +303,7 @@ class SysCommandWorker:
 
 		# https://stackoverflow.com/questions/4022600/python-pty-fork-how-does-it-work
 		if not self.pid:
-			history_logfile = pathlib.Path(f"{storage['LOG_PATH']}/cmd_history.txt")
+			history_logfile = Path(f"{storage['LOG_PATH']}/cmd_history.txt")
 
 			change_perm = False
 			if history_logfile.exists() is False:
@@ -312,14 +314,10 @@ class SysCommandWorker:
 					cmd_log.write(f"{time.time()} {self.cmd}\n")
 
 				if change_perm:
-					os.chmod(str(history_logfile), stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
+					history_logfile.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
 			except (PermissionError, FileNotFoundError):
 				# If history_logfile does not exist, ignore the error
 				pass
-			except Exception as e:
-				exception_type = type(e).__name__
-				error(f"Unexpected {exception_type} occurred in {self.cmd}: {e}")
-				raise e
 
 			if storage.get('arguments', {}).get('debug'):
 				debug(f"Executing: {self.cmd}")
@@ -350,7 +348,7 @@ class SysCommand:
 		callbacks: dict[str, Callable[[Any], Any]] = {},
 		start_callback: Callable[[Any], Any] | None = None,
 		peek_output: bool | None = False,
-		environment_vars: dict[str, Any] | None = None,
+		environment_vars: dict[str, str] | None = None,
 		working_directory: str | None = './',
 		remove_vt100_escape_codes_from_lines: bool = True):
 
@@ -379,8 +377,7 @@ class SysCommand:
 
 	def __iter__(self, *args: list[Any], **kwargs: dict[str, Any]) -> Iterator[bytes]:
 		if self.session:
-			for line in self.session:
-				yield line
+			yield from self.session
 
 	def __getitem__(self, key: slice) -> bytes | None:
 		if not self.session:
@@ -393,18 +390,10 @@ class SysCommand:
 		else:
 			raise ValueError("SysCommand() doesn't have key & value pairs, only slices, SysCommand('ls')[:10] as an example.")
 
+	@override
 	def __repr__(self, *args: list[Any], **kwargs: dict[str, Any]) -> str:
 		return self.decode('UTF-8', errors='backslashreplace') or ''
 
-	def __json__(self) -> dict[str, str | bool | list[str] | dict[str, Any] | None]:
-		return {
-			'cmd': self.cmd,
-			'callbacks': self._callbacks,
-			'peak': self.peek_output,
-			'environment_vars': self.environment_vars,
-			'session': self.session is not None
-		}
-
 	def create_session(self) -> bool:
 		"""
 		Initiates a :ref:`SysCommandWorker` session in this class ``.session``.
@@ -468,7 +457,7 @@ class SysCommand:
 
 def _pid_exists(pid: int) -> bool:
 	try:
-		return any(subprocess.check_output(['/usr/bin/ps', '--no-headers', '-o', 'pid', '-p', str(pid)]).strip())
+		return any(subprocess.check_output(['ps', '--no-headers', '-o', 'pid', '-p', str(pid)]).strip())
 	except subprocess.CalledProcessError:
 		return False
 
@@ -487,7 +476,7 @@ def run_custom_user_commands(commands: list[str], installation: Installer) -> No
 		os.unlink(chroot_path)
 
 
-def json_stream_to_structure(configuration_identifier: str, stream: str, target: dict) -> bool:
+def json_stream_to_structure(configuration_identifier: str, stream: str, target: dict[str, Any]) -> bool:
 	"""
 	Load a JSON encoded dictionary from a stream and merge it into an existing dictionary.
 	A stream can be a filepath, a URL or a raw JSON string.
@@ -506,7 +495,7 @@ def json_stream_to_structure(configuration_identifier: str, stream: str, target:
 			return False
 
 	# Try using the stream as a filepath that should be read
-	if raw is None and (path := pathlib.Path(stream)).exists():
+	if raw is None and (path := Path(stream)).exists():
 		try:
 			raw = path.read_text()
 		except Exception as err:
