@@ -2,7 +2,7 @@ import os
 from enum import Enum
 from functools import cached_property
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING
 
 from .exceptions import SysCallError
 from .general import SysCommand
@@ -10,7 +10,11 @@ from .networking import enrich_iface_types, list_interfaces
 from .output import debug
 
 if TYPE_CHECKING:
-	_: Any
+	from collections.abc import Callable
+
+	from archinstall.lib.translationhandler import DeferredTranslation
+
+	_: Callable[[str], DeferredTranslation]
 
 
 class CpuVendor(Enum):
