@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, override
 
 from archinstall.tui import Alignment, FrameProperties, MenuItem, MenuItemGroup, ResultType, SelectMenu
 
@@ -7,7 +7,11 @@ from ..menu import AbstractSubMenu
 from .utils import get_kb_layout, list_keyboard_languages, list_locales, set_kb_layout
 
 if TYPE_CHECKING:
-	_: Any
+	from collections.abc import Callable
+
+	from archinstall.lib.translationhandler import DeferredTranslation
+
+	_: Callable[[str], DeferredTranslation]
 
 
 @dataclass
@@ -65,7 +69,7 @@ class LocaleMenu(AbstractSubMenu):
 		locale_conf: LocaleConfiguration
 	):
 		self._locale_conf = locale_conf
-		self._data_store: dict[str, Any] = {}
+		self._data_store: dict[str, str] = {}
 		menu_optioons = self._define_menu_options()
 
 		self._item_group = MenuItemGroup(menu_optioons, sort_items=False, checkmarks=True)
@@ -75,21 +79,21 @@ class LocaleMenu(AbstractSubMenu):
 		return [
 			MenuItem(
 				text=str(_('Keyboard layout')),
-				action=lambda x: self._select_kb_layout(x),
+				action=self._select_kb_layout,
 				value=self._locale_conf.kb_layout,
 				preview_action=self._prev_locale,
 				key='keyboard-layout'
 			),
 			MenuItem(
 				text=str(_('Locale language')),
-				action=lambda x: select_locale_lang(x),
+				action=select_locale_lang,
 				value=self._locale_conf.sys_lang,
 				preview_action=self._prev_locale,
 				key='sys-language'
 			),
 			MenuItem(
 				text=str(_('Locale encoding')),
-				action=lambda x: select_locale_enc(x),
+				action=select_locale_enc,
 				value=self._locale_conf.sys_enc,
 				preview_action=self._prev_locale,
 				key='sys-encoding'
@@ -104,6 +108,7 @@ class LocaleMenu(AbstractSubMenu):
 		)
 		return temp_locale.preview()
 
+	@override
 	def run(self) -> LocaleConfiguration:
 		super().run()
 
