@@ -1,5 +1,5 @@
 from .audio_configuration import Audio, AudioConfiguration
 from .bootloader import Bootloader
-from .gen import LocalPackage, PackageSearch, PackageSearchResult, VersionDef
+from .gen import LocalPackage, PackageSearch, PackageSearchResult
 from .network_configuration import NetworkConfiguration, Nic, NicType
 from .users import PasswordStrength, User
