@@ -1,47 +1,46 @@
 from dataclasses import dataclass
-from enum import Enum
-from typing import Any
+from enum import StrEnum, auto
 
 from ...default_profiles.applications.pipewire import PipewireProfile
 from ..hardware import SysInfo
+from ..installer import Installer
 from ..output import info
 
 
-@dataclass
-class Audio(Enum):
-	NoAudio = 'No audio server'
-	Pipewire = 'pipewire'
-	Pulseaudio = 'pulseaudio'
+class Audio(StrEnum):
+	NO_AUDIO = 'No audio server'
+	PIPEWIRE = auto()
+	PULSEAUDIO = auto()
 
 
 @dataclass
 class AudioConfiguration:
 	audio: Audio
 
-	def json(self) -> dict[str, Any]:
+	def json(self) -> dict[str, str]:
 		return {
 			'audio': self.audio.value
 		}
 
 	@staticmethod
-	def parse_arg(arg: dict[str, Any]) -> 'AudioConfiguration':
+	def parse_arg(arg: dict[str, str]) -> 'AudioConfiguration':
 		return AudioConfiguration(
 			Audio(arg['audio'])
 		)
 
 	def install_audio_config(
 		self,
-		installation: Any
+		installation: Installer
 	) -> None:
 		info(f'Installing audio server: {self.audio.name}')
 
 		match self.audio:
-			case Audio.Pipewire:
+			case Audio.PIPEWIRE:
 				PipewireProfile().install(installation)
-			case Audio.Pulseaudio:
+			case Audio.PULSEAUDIO:
 				installation.add_additional_packages("pulseaudio")
 
-		if self.audio != Audio.NoAudio:
+		if self.audio != Audio.NO_AUDIO:
 			if SysInfo.requires_sof_fw():
 				installation.add_additional_packages('sof-firmware')
 
