@@ -1,61 +1,5 @@
 from dataclasses import dataclass
-from typing import Any
-
-
-@dataclass
-class VersionDef:
-	version_string: str
-
-	@classmethod
-	def parse_version(cls) -> list[str]:
-		if '.' in cls.version_string:
-			versions = cls.version_string.split('.')
-		else:
-			versions = [cls.version_string]
-
-		return versions
-
-	@classmethod
-	def major(self) -> str:
-		return self.parse_version()[0]
-
-	@classmethod
-	def minor(cls) -> str | None:
-		versions = cls.parse_version()
-		if len(versions) >= 2:
-			return versions[1]
-
-		return None
-
-	@classmethod
-	def patch(cls) -> str | None:
-		versions = cls.parse_version()
-		if '-' in versions[-1]:
-			_, patch_version = versions[-1].split('-', 1)
-			return patch_version
-
-		return None
-
-	def __eq__(self, other) -> bool:
-		if other.major == self.major and \
-			other.minor == self.minor and \
-			other.patch == self.patch:
-
-			return True
-		return False
-
-	def __lt__(self, other) -> bool:
-		if self.major() > other.major():
-			return False
-		elif self.minor() and other.minor() and self.minor() > other.minor():
-			return False
-		elif self.patch() and other.patch() and self.patch() > other.patch():
-			return False
-
-		return True
-
-	def __str__(self) -> str:
-		return self.version_string
+from typing import Any, override
 
 
 @dataclass
@@ -95,7 +39,11 @@ class PackageSearchResult:
 	def pkg_version(self) -> str:
 		return self.pkgver
 
-	def __eq__(self, other) -> bool:
+	@override
+	def __eq__(self, other: object) -> bool:
+		if not isinstance(other, PackageSearchResult):
+			return NotImplemented
+
 		return self.pkg_version == other.pkg_version
 
 	def __lt__(self, other: 'PackageSearchResult') -> bool:
@@ -153,7 +101,11 @@ class LocalPackage:
 	def pkg_version(self) -> str:
 		return self.version
 
-	def __eq__(self, other) -> bool:
+	@override
+	def __eq__(self, other: object) -> bool:
+		if not isinstance(other, LocalPackage):
+			return NotImplemented
+
 		return self.pkg_version == other.pkg_version
 
 	def __lt__(self, other: 'LocalPackage') -> bool:
