@@ -20,7 +20,7 @@ class FormattedOutput:
 	def _get_values(
 		cls,
 		o: 'DataclassInstance',
-		class_formatter: str | Callable | None = None,
+		class_formatter: str | Callable | None = None,  # type: ignore[type-arg]
 		filter_list: list[str] = []
 	) -> dict[str, Any]:
 		"""
@@ -52,7 +52,7 @@ class FormattedOutput:
 	def as_table(
 		cls,
 		obj: list[Any],
-		class_formatter: str | Callable | None = None,
+		class_formatter: str | Callable | None = None,  # type: ignore[type-arg]
 		filter_list: list[str] = [],
 		capitalize: bool = False
 	) -> str:
@@ -133,7 +133,7 @@ class Journald:
 	@staticmethod
 	def log(message: str, level: int = logging.DEBUG) -> None:
 		try:
-			import systemd.journal  # type: ignore
+			import systemd.journal  # type: ignore[import-not-found]
 		except ModuleNotFoundError:
 			return None
 
@@ -237,7 +237,7 @@ def _stylize_output(
 	code_list = []
 
 	if text == '' and reset:
-		return '\x1b[%sm' % '0'
+		return '\x1b[0m'
 
 	code_list.append(foreground[str(fg)])
 
