@@ -14,17 +14,20 @@ from ...default_profiles.profile import GreeterType, Profile
 from ..hardware import GfxDriver
 from ..networking import fetch_data_from_url, list_interfaces
 from ..output import debug, error, info
-from ..storage import storage
 from .profile_model import ProfileConfiguration
 
 if TYPE_CHECKING:
+	from collections.abc import Callable
+
+	from archinstall.lib.translationhandler import DeferredTranslation
+
 	from ..installer import Installer
-	_: Any
+
+	_: Callable[[str], DeferredTranslation]
 
 
 class ProfileHandler:
 	def __init__(self) -> None:
-		self._profiles_path: Path = storage['PROFILE']
 		self._profiles: list[Profile] | None = None
 
 		# special variable to keep track of a profile url configuration
@@ -161,21 +164,20 @@ class ProfileHandler:
 		return next(filter(lambda x: x.name == name, self.profiles), None)  # type: ignore
 
 	def get_top_level_profiles(self) -> list[Profile]:
-		return list(filter(lambda x: x.is_top_level_profile(), self.profiles))
+		return [p for p in self.profiles if p.is_top_level_profile()]
 
 	def get_server_profiles(self) -> list[Profile]:
-		return list(filter(lambda x: x.is_server_type_profile(), self.profiles))
+		return [p for p in self.profiles if p.is_server_type_profile()]
 
 	def get_desktop_profiles(self) -> list[Profile]:
-		return list(filter(lambda x: x.is_desktop_type_profile(), self.profiles))
+		return [p for p in self.profiles if p.is_desktop_type_profile()]
 
 	def get_custom_profiles(self) -> list[Profile]:
-		return list(filter(lambda x: x.is_custom_type_profile(), self.profiles))
+		return [p for p in self.profiles if p.is_custom_type_profile()]
 
 	def get_mac_addr_profiles(self) -> list[Profile]:
-		tailored = list(filter(lambda x: x.is_tailored(), self.profiles))
-		match_mac_addr_profiles = list(filter(lambda x: x.name in self._local_mac_addresses, tailored))
-		return match_mac_addr_profiles
+		tailored = [p for p in self.profiles if p.is_tailored()]
+		return [t for t in tailored if t.name in self._local_mac_addresses]
 
 	def install_greeter(self, install_session: 'Installer', greeter: GreeterType) -> None:
 		packages = []
@@ -273,7 +275,7 @@ class ProfileHandler:
 		Load all default_profiles defined in a module
 		"""
 		profiles = []
-		for k, v in module.__dict__.items():
+		for v in module.__dict__.values():
 			if isinstance(v, type) and v.__module__ == module.__name__:
 				bases = inspect.getmro(v)
 
@@ -293,7 +295,7 @@ class ProfileHandler:
 		that the provided list contains only default_profiles with unique names
 		"""
 		counter = Counter([p.name for p in profiles])
-		duplicates = list(filter(lambda x: x[1] != 1, counter.items()))
+		duplicates = [x for x in counter.items() if x[1] != 1]
 
 		if len(duplicates) > 0:
 			err = str(_('Profiles must have unique name, but profile definitions with duplicate name found: {}')).format(duplicates[0][0])
@@ -341,8 +343,9 @@ class ProfileHandler:
 		"""
 		Search the profile path for profile definitions
 		"""
+		profiles_path = Path(__file__).parents[2] / 'default_profiles'
 		profiles = []
-		for file in self._profiles_path.glob('**/*.py'):
+		for file in profiles_path.glob('**/*.py'):
 			# ignore the abstract default_profiles class
 			if 'profile.py' in file.name:
 				continue
