@@ -5,7 +5,7 @@ import json
 import os
 from dataclasses import dataclass
 from pathlib import Path
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, override
 
 from .output import debug, error
 
@@ -59,7 +59,7 @@ class TranslationHandler:
 		languages = []
 
 		for short_form in defined_languages:
-			mapping_entry: dict[str, Any] = next(filter(lambda x: x['abbr'] == short_form, mappings))
+			mapping_entry: dict[str, str] = next(filter(lambda x: x['abbr'] == short_form, mappings))
 			abbr = mapping_entry['abbr']
 			lang = mapping_entry['lang']
 			translated_lang = mapping_entry.get('translated_lang', None)
@@ -95,7 +95,7 @@ class TranslationHandler:
 		except Exception:
 			error(f'Unable to set font {font}')
 
-	def _load_language_mappings(self) -> list[dict[str, Any]]:
+	def _load_language_mappings(self) -> list[dict[str, str]]:
 		"""
 		Load the mapping table of all known languages
 		"""
@@ -111,7 +111,7 @@ class TranslationHandler:
 		"""
 		# this is a very naughty way of retrieving the data but
 		# there's no alternative method exposed unfortunately
-		catalog = translation._catalog  # type: ignore
+		catalog = translation._catalog  # type: ignore[attr-defined]
 		messages = {k: v for k, v in catalog.items() if k and v}
 		return len(messages)
 
@@ -180,6 +180,7 @@ class DeferredTranslation:
 	def __len__(self) -> int:
 		return len(self.message)
 
+	@override
 	def __str__(self) -> str:
 		translate = _
 		if translate is DeferredTranslation:
@@ -205,4 +206,7 @@ class DeferredTranslation:
 	@classmethod
 	def install(cls) -> None:
 		import builtins
-		builtins._ = cls  # type: ignore
+		builtins._ = cls  # type: ignore[attr-defined]
+
+
+translation_handler = TranslationHandler()
