@@ -18,37 +18,37 @@ class STYLE(Enum):
 
 class MenuKeys(Enum):
 	# latin keys
-	STD_KEYS = set(range(32, 127))
+	STD_KEYS = frozenset(range(32, 127))
 	# numbers
-	NUM_KEYS = set(range(49, 58))
+	NUM_KEYS = frozenset(range(49, 58))
 	# Menu up: up, k
-	MENU_UP = {259, 107}
+	MENU_UP = frozenset({259, 107})
 	# Menu down: down, j
-	MENU_DOWN = {258, 106}
+	MENU_DOWN = frozenset({258, 106})
 	# Menu left: left, h
-	MENU_LEFT = {260, 104}
+	MENU_LEFT = frozenset({260, 104})
 	# Menu right: right, l
-	MENU_RIGHT = {261, 108}
+	MENU_RIGHT = frozenset({261, 108})
 	# Menu start: home CTRL-a
-	MENU_START = {262, 1}
+	MENU_START = frozenset({262, 1})
 	# Menu end: end CTRL-e
-	MENU_END = {360, 5}
+	MENU_END = frozenset({360, 5})
 	# Enter
-	ACCEPT = {10}
+	ACCEPT = frozenset({10})
 	# Selection: space, tab
-	MULTI_SELECT = {32, 9}
+	MULTI_SELECT = frozenset({32, 9})
 	# Search: /
-	ENABLE_SEARCH = {47}
+	ENABLE_SEARCH = frozenset({47})
 	# ESC
-	ESC = {27}
+	ESC = frozenset({27})
 	# BACKSPACE (search)
-	BACKSPACE = {127, 263}
-	# Help view: ?
-	HELP = {63}
-	# Scroll up: CTRL+up, CTRL+k
-	SCROLL_UP = {581}
-	# Scroll down: CTRL+down, CTRL+j
-	SCROLL_DOWN = {540}
+	BACKSPACE = frozenset({127, 263})
+	# Help view: ctrl+h
+	HELP = frozenset({8})
+	# Scroll up: PGUP
+	SCROLL_UP = frozenset({339})
+	# Scroll down: PGDOWN
+	SCROLL_DOWN = frozenset({338})
 
 	@classmethod
 	def from_ord(cls, key: int) -> list['MenuKeys']:
